#!/bin/sh -e
# Author: prx <prx@si3t.ch>
# licence: MIT
# Description: add new user to the server and generate instructions
# Depends: libqrencode (qrencode)

. /etc/tabr.conf

die()
{
	printf "%s\n" "$*"
	exit 1
}

usage()
{
	printf "%s <username> <recovery-passphrase>\n" "$0"
	printf "if not specified, a random recovery-passphrase will be generated\n"
	exit 1
}

genpw()
{
	#jot -rcs '' $1 33 126
	tr -cd '[:alnum:]~#()%@,?;.!*' < /dev/urandom |\
		fold -w $1 | head -n 1
}

rdm-recovery-pass()
{
	genpw 30 |
		sed -E 's/^(.{6})(.{6})(.{6})(.{6})/\1-\2-\3-\4-/'
}

## get arguments into variables
[[ $# -ge 1 ]] && [[ $# -lt 3 ]] || usage

u="${1}"
[[ -z "${2}" ]] && recovery="$(rdm-recovery-pass)" || recovery="${2}"

## check if user already exist
id -u $u > /dev/null 2>&1 && die "User already exists"
#[[ -e $data/$u ]] && die "User already exists" # commented, previous is safer

## generate random password
pw="$(genpw 16)"

## store recovery pass
encrypt -b a ${recovery} > $data/$u

## create system user
doas /usr/sbin/useradd -m -g $usergroup -s /sbin/nologin -p "$(encrypt -b a "${pw}")" "$u"

## create xmpp account
printf "%s\n%s\n" "${pw}" "${pw}" | doas /usr/local/sbin/prosodyctl adduser "${u}@${domain}"

## dokuwiki ?
## nextcloud ?

## generate notice with qr code
print_notice "${u}" "${pw}" "${recovery}" |\ 
	mail -s "New USER: ${u}" ${admin}
