#!/bin/sh 
# Author: prx <prx@si3t.ch>
# licence: MIT
# Description: change tabr_user password in various services

. /etc/tabr.conf

usage()
{
	printf "%s\n" "$0 <directory containing requests>"
	exit 1
}

end()
{
	# $1 : file
	# $2 : message
	# $3 : exit code

	## alert root
	cat << EOF | mail -s "$(basename $1) password change request" ${admin}
$1 was created to change password and returned:
$2
EOF
	rm -f "$1"

	exit $3
}

handle_request() {
	u="$(basename ${1})"

	## check if user is indeed registered
	[[ -e $data/$u ]] || end "${1}" "No user $u found" 1

	## check if recovery match user hashed recovery
	# recovery is on first line
	#recovery="$(sed -n '1p' ${1})"
	head -n 1 "${1}" | /usr/local/bin/hashmatchstr $(cat ${data}/${u}) \
		|| end "${1}" "Wrong recovery code" 1


	newpw="$(sed -n '2p' ${1})" # pw on 2nd line
	newpwhash="$(print "%s" "${newpw}" | encrypt -b a )"

	## change system pw
	doas /usr/sbin/usermod -p "${newpwhash}" "${u}"

	## xmpp
	printf "%s\n%s\n" "${newpw}" "${newpw}" | 
		doas /usr/local/sbin/prosodyctl passwd "${u}@${domain}"

	end ${1} "Everything seems OK" 0
}


[[ $# -ne 1 ]] && usage

# loop over file lists
find "$1"/ -type f | while read -r request_file; do
	handle_request "${request_file}"
done

